Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(26)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestDynamicShippingMultipleAddressesTest.java

Issue 2800803002: Fix test expectation. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestBillingAddressTest.java ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestDynamicShippingMultipleAddressesTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestDynamicShippingMultipleAddressesTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestDynamicShippingMultipleAddressesTest.java
index b70c27c7f67b75cd375f8047ea1506f5de3c9d3d..d546bca64dd7bb736aba8ad53766245f52ac7d18 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestDynamicShippingMultipleAddressesTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestDynamicShippingMultipleAddressesTest.java
@@ -21,40 +21,40 @@ import java.util.concurrent.TimeoutException;
*/
public class PaymentRequestDynamicShippingMultipleAddressesTest extends PaymentRequestTestBase {
private static final AutofillProfile[] AUTOFILL_PROFILES = {
- // Incomplete profile (missing phone number)
- new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
- "Bart Simpson", "Acme Inc.", "123 Main", "California", "Los Angeles", "",
- "90210", "", "US", "", "bart@simpson.com", ""),
-
- // Incomplete profile (missing street address).
- new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
- "Homer Simpson", "Acme Inc.", "", "California", "Los Angeles", "",
- "90210", "", "US", "555 123-4567", "homer@simpson.com", ""),
-
- // Complete profile.
- new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
- "Lisa Simpson", "Acme Inc.", "123 Main", "California", "Los Angeles", "",
- "90210", "", "US", "555 123-4567", "lisa@simpson.com", ""),
-
- // Complete profile in another country.
- new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
- "Maggie Simpson", "Acme Inc.", "123 Main", "California", "Los Angeles", "",
- "90210", "", "Uzbekistan", "555 123-4567", "maggie@simpson.com", ""),
-
- // Incomplete profile (invalid address).
- new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
- "Marge Simpson", "Acme Inc.", "123 Main", "California", "", "",
- "90210", "", "US", "555 123-4567", "marge@simpson.com", ""),
-
- // Incomplete profile (missing recipient).
- new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
- "", "Acme Inc.", "123 Main", "California", "Los Angeles", "",
- "90210", "", "US", "555 123-4567", "lisa@simpson.com", ""),
-
- // Incomplete profile (need more information).
- new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
- "", "Acme Inc.", "123 Main", "California", "", "",
- "90210", "", "US", "555 123-4567", "lisa@simpson.com", ""),
+ // Incomplete profile (missing phone number)
+ new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
+ "Bart Simpson", "Acme Inc.", "123 Main", "California", "Los Angeles", "",
+ "90210", "", "US", "", "bart@simpson.com", ""),
+
+ // Incomplete profile (missing street address).
+ new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
+ "Homer Simpson", "Acme Inc.", "", "California", "Los Angeles", "", "90210", "",
+ "US", "555 123-4567", "homer@simpson.com", ""),
+
+ // Complete profile.
+ new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
+ "Lisa Simpson", "Acme Inc.", "123 Main", "California", "Los Angeles", "",
+ "90210", "", "US", "555 123-4567", "lisa@simpson.com", ""),
+
+ // Complete profile in another country.
+ new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
+ "Maggie Simpson", "Acme Inc.", "123 Main", "California", "Los Angeles", "",
+ "90210", "", "Uzbekistan", "555 123-4567", "maggie@simpson.com", ""),
+
+ // Incomplete profile (invalid address).
+ new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */,
+ "Marge Simpson", "Acme Inc.", "123 Main", "California", "", "", "90210", "",
+ "US", "555 123-4567", "marge@simpson.com", ""),
+
+ // Incomplete profile (missing recipient name).
+ new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */, "",
+ "Acme Inc.", "123 Main", "California", "Los Angeles", "", "90210", "", "US",
+ "555 123-4567", "lisa@simpson.com", ""),
+
+ // Incomplete profile (need more information).
+ new AutofillProfile("" /* guid */, "https://www.example.com" /* origin */, "",
+ "Acme Inc.", "123 Main", "California", "", "", "90210", "", "US",
+ "555 123-4567", "lisa@simpson.com", ""),
};
private AutofillProfile[] mProfilesToAdd;
@@ -205,7 +205,7 @@ public class PaymentRequestDynamicShippingMultipleAddressesTest extends PaymentR
assertEquals(4, getNumberOfShippingAddressSuggestions());
assertTrue(getShippingAddressSuggestionLabel(0).contains("Phone number required"));
assertTrue(getShippingAddressSuggestionLabel(1).contains("Invalid address"));
- assertTrue(getShippingAddressSuggestionLabel(2).contains("Recipient required"));
+ assertTrue(getShippingAddressSuggestionLabel(2).contains("Name required"));
assertTrue(getShippingAddressSuggestionLabel(3).contains("More information required"));
}
}
« no previous file with comments | « chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestBillingAddressTest.java ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698